Page 174 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 174

Home

    collectivists continued to predict the downfall of the
    organization. Fifteen years later the Society celebrated its
    25th Anniversary and Robert Welch would be presented
    the keys to the city of Indianapolis.

    And now, 35 years have passed by, the last nine
    without the presence of our founder. This organization
    which has suffered such vilification as no other, certainly
    in this century, had not only survived, but in the process
    has provided solid information, direction, hope and
    encouragement to millions and millions of our

    millions

    countrymen. What is more, its goals remain the same;
    and its principles, and organizational body are intact.
    Perhaps the single most important reason why the
    Society is alive and well today, is because sufficient
    numbers of its members went to the trouble of reaching
    others with enough information, rather than too little.

    that it was far more than just an anti-communist
    organization. Its leadership and members understood the
    real basis of the struggle going on in the world. Society
    spokesman, G. Edward Griffin, explains this struggle and
    what is necessary to defeat it:

    The war raging around the world today is not
    between communists and anti-communists. As words

    are misleading, a better word to use to describe the
    forces here is the forces of collectivism verses the forces

    A collectivist is a person who believes that the
    collective is more important than the individual, that the
    group is more important than the individual, and the

    169

    A New Movement in History

    And still the chorus of the above mentioned collection of

    encouragement to
    . wm.

    One of the reasons the JBS influenced millions was

    of individualism.